==> feeds_fetcher_post-1.0.0-alpha1.tar.gz: feeds_fetcher_post/src/Feeds/Fetcher/HttpFetcherPost.php <==
<?php

namespace Drupal\feeds_fetcher_post\Feeds\Fetcher;

use Drupal\feeds\Exception\EmptyFeedException;
use Drupal\feeds\Feeds\Fetcher\HttpFetcher;
use Drupal\feeds\Result\HttpFetcherResult;
use Drupal\feeds\StateInterface;
use Drupal\feeds\Utility\Feed;
use GuzzleHttp\Exception\RequestException;
use GuzzleHttp\RequestOptions;
use Symfony\Component\HttpFoundation\Response;
use Drupal\feeds\FeedInterface;

/**
 * Defines an HTTP Post fetcher.
 *
 * @FeedsFetcher(
 *   id = "httpfetcherpost",
 *   title = @Translation("Download from URL additional POST parameters"),
 *   description = @Translation("Downloads data from a URL using Drupal's HTTP request handler with additional POST parameters."),
 *   form = {
 *     "configuration" = "Drupal\feeds\Feeds\Fetcher\Form\HttpFetcherForm",
 *     "feed" = "Drupal\feeds_fetcher_post\Feeds\Fetcher\Form\HttpFetcherPostFeedForm",
 *   }
 * )
 */
class HttpFetcherPost extends HTTPFetcher {

  /**
   * {@inheritdoc}
   */
  public function defaultFeedConfiguration() {
    $default_configuration = parent::defaultConfiguration();
    $default_configuration['post_parameter'] = '';
    $default_configuration['httpmethod'] = '';
    return $default_configuration;
  }

  /**
   * {@inheritdoc}
   */
  public function fetch(FeedInterface $feed, StateInterface $state) {
    $sink = $this->fileSystem->tempnam('temporary://', 'feeds_http_fetcher');
    $sink = $this->fileSystem->realpath($sink);

    $response = $this->post($feed->getSource(), $sink, $this->getCacheKey($feed), $feed->getConfigurationFor($this)['post_parameter']);
    // @todo Handle redirects.
    // @codingStandardsIgnoreStart
    // $feed->setSource($response->getEffectiveUrl());
    // @codingStandardsIgnoreEnd

    // 304, nothing to see here.
    if ($response->getStatusCode() == Response::HTTP_NOT_MODIFIED) {
      $state->setMessage($this->t('The feed has not been updated.'));
      throw new EmptyFeedException();
    }

    return new HttpFetcherResult($sink, $response->getHeaders());
  }

  /**
   * Performs a POST request.
   *
   * @param string $url
   *   The URL to POST.
   * @param string $sink
   *   The location where the downloaded content will be saved. This can be a
   *   resource, path or a StreamInterface object.
   * @param string $cache_key
   *   (optional) The cache key to find cached headers. Defaults to false.
   * @param string $post_parameter
   *   (optional) The post_parameter or form fields. Defaults to ''.
   *
   * @return \Guzzle\Http\Message\Response
   *   A Guzzle response.
   *
   * @throws \RuntimeException
   *   Thrown if the POST request failed.
   *
   * @see \GuzzleHttp\RequestOptions
   */
  protected function post($url, $sink, $cache_key = FALSE, $post_parameter = '') {
    $url = Feed::translateSchemes($url);

    $options = [RequestOptions::SINK => $sink];

    if ($post_parameter !== '') {
      foreach (explode("\r\n", $post_parameter) as $row) {
        if (preg_match('/(.*?): (.*)/', $row, $matches)) {
          $options[RequestOptions::FORM_PARAMS][$matches[1]] = $matches[2];
        }
      }
    }

    // Add cached headers if requested.
    if ($cache_key && ($cache = $this->cache->get($cache_key))) {
      if (isset($cache->data['etag'])) {
        $options[RequestOptions::HEADERS]['If-None-Match'] = $cache->data['etag'];
      }
      if (isset($cache->data['last-modified'])) {
        $options[RequestOptions::HEADERS]['If-Modified-Since'] = $cache->data['last-modified'];
      }
    }

    try {
      $response = $this->client->post($url, $options);
    }
    catch (RequestException $e) {
      $args = [
        '%site' => $url,
        '%error' => $e->getMessage(),
        '%post_parameter' => $post_parameter,
      ];
      throw new \RuntimeException($this->t('The feed from %site seems to be broken because of error "%error". %post_parameter', $args));
    }

    if ($cache_key) {
      $this->cache->set($cache_key, array_change_key_case($response->getHeaders()));
    }
    return $response;
  }

}

==> feeds_fetcher_post-2.0.0-alpha1.tar.gz: feeds_fetcher_post/src/Feeds/Fetcher/HttpFetcherPost.php <==
<?php

namespace Drupal\feeds_fetcher_post\Feeds\Fetcher;

use Drupal\feeds\Exception\EmptyFeedException;
use Drupal\feeds\FeedInterface;
use Drupal\feeds\Feeds\Fetcher\HttpFetcher;
use Drupal\feeds\Result\HttpFetcherResult;
use Drupal\feeds\StateInterface;
use Drupal\feeds\Utility\Feed;
use GuzzleHttp\Exception\RequestException;
use GuzzleHttp\RequestOptions;
use Symfony\Component\HttpFoundation\Response;

/**
 * Defines an HTTP Post fetcher.
 *
 * @FeedsFetcher(
 *   id = "httpfetcherpost",
 *   title = @Translation("Download from URL additional POST parameters"),
 *   description = @Translation("Downloads data from a URL using Drupal's HTTP request handler with additional POST parameters."),
 *   form = {
 *     "configuration" = "Drupal\feeds\Feeds\Fetcher\Form\HttpFetcherForm",
 *     "feed" = "Drupal\feeds_fetcher_post\Feeds\Fetcher\Form\HttpFetcherPostFeedForm",
 *   }
 * )
 */
class HttpFetcherPost extends HTTPFetcher {

  /**
   * {@inheritdoc}
   */
  public function defaultFeedConfiguration() {
    $default_configuration = parent::defaultConfiguration();
    $default_configuration['headers'] = '';
    $default_configuration['post_parameter'] = '';
    $default_configuration['post_variant'] = 'FORM_PARAMS';
    return $default_configuration;
  }

  /**
   * {@inheritdoc}
   */
  public function fetch(FeedInterface $feed, StateInterface $state) {
    $sink = $this->fileSystem->tempnam('temporary://', 'feeds_http_fetcher');
    $sink = $this->fileSystem->realpath($sink);

    $response = $this->post($feed->getSource(), $sink, $this->getCacheKey($feed),
      $feed->getConfigurationFor($this)['headers'], $feed->getConfigurationFor($this)['post_parameter'],
      $feed->getConfigurationFor($this)['post_variant']);

    // 304, nothing to see here.
    if ($response->getStatusCode() == Response::HTTP_NOT_MODIFIED) {
      $state->setMessage($this->t('The feed has not been updated.'));
      throw new EmptyFeedException();
    }

    return new HttpFetcherResult($sink, $response->getHeaders());
  }

  /**
   * Performs a POST request.
   *
   * @param string $url
   *   The URL to POST.
   * @param string $sink
   *   The location where the downloaded content will be saved. This can be a
   *   resource, path or a StreamInterface object.
   * @param string $cache_key
   *   (optional) The cache key to find cached headers. Defaults to false.
   * @param string $headers
   *   (optional) The headers or form fields. Defaults to ''.
   * @param string $post_parameter
   *   (optional) The post_parameter or form fields. Defaults to ''.
   * @param string $post_variant
   *   (optional) The variant FORM_PARAMS or BODY. Defaults to FORM_PARAMS.
   *
   * @return \Psr\Http\Message\ResponseInterface
   *   A Guzzle response.
   *
   * @throws \RuntimeException
   *   Thrown if the POST request failed.
   *
   * @see \GuzzleHttp\RequestOptions
   */
  protected function post($url, $sink, $cache_key, $headers = '', $post_parameter = '', $post_variant = 'FORM_PARAMS') {
    $url = Feed::translateSchemes($url);

    $options = [RequestOptions::SINK => $sink];

    if ($headers !== '') {
      foreach (explode("\r\n", $headers) as $row) {
        if (preg_match('/(.*?): (.*)/', $row, $matches)) {
          $options[RequestOptions::HEADERS][$matches[1]] = $matches[2];
        }
      }
    }
    if ($post_parameter !== '') {
      if ($post_variant === 'BODY') {
        $options[RequestOptions::BODY] = $post_parameter;
      }
      else {
        foreach (explode("\r\n", $post_parameter) as $row) {
          if (preg_match('/(.*?): (.*)/', $row, $matches)) {
            $options[RequestOptions::FORM_PARAMS][$matches[1]] = $matches[2];
          }
        }
      }
    }

    // Add cached headers if requested.
    if ($cache_key && ($cache = $this->cache->get($cache_key))) {
      if (isset($cache->data['etag'])) {
        $options[RequestOptions::HEADERS]['If-None-Match'] = $cache->data['etag'];
      }
      if (isset($cache->data['last-modified'])) {
        $options[RequestOptions::HEADERS]['If-Modified-Since'] = $cache->data['last-modified'];
      }
    }

    try {
      $response = $this->client->request('POST', $url, $options);
    }
    catch (RequestException $e) {
      $args = [
        '%site' => $url,
        '%error' => $e->getMessage(),
        '%headers' => $headers,
        '%post_parameter' => $post_parameter,
      ];
      throw new \RuntimeException(str_replace(array_keys($args), array_values($args), 'The feed from %site seems to be broken because of error "%error". %headers %post_parameter'));
    }

    if ($cache_key !== '') {
      $this->cache->set($cache_key, array_change_key_case($response->getHeaders()));
    }
    return $response;
  }

}
